{% load seeker %}

<label for="{{ facet.name }}_low">{{ facet.label|capfirst }}</label>
<div class="seeker-range">
    <input type="text" size="3" class="form-control" name="{{ facet.field }}" value="{{ selected.0 }}" id="{{ facet.name }}_low" style="width:auto;display:inline-block;" />
    to
    <input type="text" size="3" class="form-control" name="{{ facet.field }}" value="{{ selected.1 }}" id="{{ facet.name }}_high" style="width:auto;display:inline-block;" />
</div>
